Mapper Configuration — SQLAlchemy 1.3 Documentation

Release: 1.3.24 | Release Date: March 30, 2021

# SQLAlchemy 1.3 Documentation

# Mapper Configuration

This section describes a variety of configurational patterns that are usable with mappers. It assumes you’ve worked through Object Relational Tutorial and know how to construct and use rudimentary mappers and relationships.

- Types of Mappings
  - Declarative Mapping
  - Classical Mappings
  - Runtime Introspection of Mappings, Objects
- Mapping Columns and Expressions
  - Mapping Table Columns
  - SQL Expressions as Mapped Attributes
  - Changing Attribute Behavior
  - Composite Column Types
- Mapping Class Inheritance Hierarchies
  - Joined Table Inheritance
  - Single Table Inheritance
  - Concrete Table Inheritance
- Non-Traditional Mappings
  - Mapping a Class against Multiple Tables
  - Mapping a Class against Arbitrary Selects
  - Multiple Mappers for One Class
- Configuring a Version Counter
  - Simple Version Counting
  - Custom Version Counters / Types
  - Server Side Version Counters
  - Programmatic or Conditional Version Counters
- Class Mapping API